==> jc-1.4.0.tar.gz: java/lang/NoClassDefFoundError.h <==
// public class java.lang.NoClassDefFoundError

// class file dependencies
// @dep_class 308333d803f5ab9f java_lang_Error
// @dep_class 3746e17e005bda9e java_lang_LinkageError
// @dep_class 2082ebb592ac2255 java_lang_NoClassDefFoundError
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable

// header file dependencies
// @dep_header java_lang_LinkageError

#include "java/lang/LinkageError.h"

#ifndef _JC_java_lang_NoClassDefFoundError_H_
#define _JC_java_lang_NoClassDefFoundError_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_lang_NoClassDefFoundError$sub_refs	_jc_java_lang_NoClassDefFoundError$sub_refs;
typedef struct _jc_java_lang_NoClassDefFoundError$sub_nonrefs	_jc_java_lang_NoClassDefFoundError$sub_nonrefs;
typedef struct _jc_java_lang_NoClassDefFoundError$refs	_jc_java_lang_NoClassDefFoundError$refs;
typedef struct _jc_java_lang_NoClassDefFoundError$nonrefs	_jc_java_lang_NoClassDefFoundError$nonrefs;
typedef struct _jc_java_lang_NoClassDefFoundError$object	_jc_java_lang_NoClassDefFoundError$object;

typedef struct _jc_java_lang_NoClassDefFoundError$fields_struct	_jc_java_lang_NoClassDefFoundError$fields_struct;
typedef const struct _jc_java_lang_NoClassDefFoundError$vmethods	_jc_java_lang_NoClassDefFoundError$vmethods;
typedef const struct _jc_java_lang_NoClassDefFoundError$vtable	_jc_java_lang_NoClassDefFoundError$vtable;
typedef const struct _jc_java_lang_NoClassDefFoundError$vtype	_jc_java_lang_NoClassDefFoundError$vtype;

// Class fields structure
struct _jc_java_lang_NoClassDefFoundError$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_lang_NoClassDefFoundError$fields_struct _jc_java_lang_NoClassDefFoundError$class_fields;

// Constructors
extern void _jc_java_lang_NoClassDefFoundError$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_lang_NoClassDefFoundError$object *);
extern void _jc_java_lang_NoClassDefFoundError$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_lang_NoClassDefFoundError$object *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_java_lang_NoClassDefFoundError$vmethods {
};

// Vtable
struct _jc_java_lang_NoClassDefFoundError$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Error$vmethods	java_lang_Error;
	_jc_java_lang_LinkageError$vmethods	java_lang_LinkageError;
	_jc_java_lang_NoClassDefFoundError$vmethods	java_lang_NoClassDefFoundError;
};

// Vtype
struct _jc_java_lang_NoClassDefFoundError$vtype {
	_jc_type			type;
	_jc_java_lang_NoClassDefFoundError$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_NoClassDefFoundError$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_lang_NoClassDefFoundError$refs {
    _jc_java_lang_NoClassDefFoundError$sub_refs	java_lang_NoClassDefFoundError;
    _jc_java_lang_LinkageError$sub_refs	java_lang_LinkageError;
    _jc_java_lang_Error$sub_refs	java_lang_Error;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_NoClassDefFoundError$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_lang_NoClassDefFoundError$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Error$sub_nonrefs	java_lang_Error;
    _jc_java_lang_LinkageError$sub_nonrefs	java_lang_LinkageError;
    _jc_java_lang_NoClassDefFoundError$sub_nonrefs	java_lang_NoClassDefFoundError;
};

// Object instance structure
struct _jc_java_lang_NoClassDefFoundError$object {
	_jc_java_lang_NoClassDefFoundError$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_NoClassDefFoundError$vtype	*vtype;
	_jc_java_lang_NoClassDefFoundError$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_NoClassDefFoundError$vtype _jc_java_lang_NoClassDefFoundError$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_NoClassDefFoundError, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_NoClassDefFoundError$class_object;

#endif	/* _JC_java_lang_NoClassDefFoundError_H_ */

==> jc-1.4.6.tar.gz: java/lang/NoClassDefFoundError.h <==
// public class java.lang.NoClassDefFoundError

// class file dependencies
// @dep_class 308333d803f5ab9f java_lang_Error
// @dep_class 3746e17e005bda9e java_lang_LinkageError
// @dep_class 2082ebb592ac2255 java_lang_NoClassDefFoundError
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable

// header file dependencies
// @dep_header java_lang_LinkageError

#include "java/lang/LinkageError.h"

#ifndef _JC_java_lang_NoClassDefFoundError_H_
#define _JC_java_lang_NoClassDefFoundError_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_lang_NoClassDefFoundError$sub_refs	_jc_java_lang_NoClassDefFoundError$sub_refs;
typedef struct _jc_java_lang_NoClassDefFoundError$sub_nonrefs	_jc_java_lang_NoClassDefFoundError$sub_nonrefs;
typedef struct _jc_java_lang_NoClassDefFoundError$refs	_jc_java_lang_NoClassDefFoundError$refs;
typedef struct _jc_java_lang_NoClassDefFoundError$nonrefs	_jc_java_lang_NoClassDefFoundError$nonrefs;
typedef struct _jc_java_lang_NoClassDefFoundError$object	_jc_java_lang_NoClassDefFoundError$object;

typedef struct _jc_java_lang_NoClassDefFoundError$fields_struct	_jc_java_lang_NoClassDefFoundError$fields_struct;
typedef const struct _jc_java_lang_NoClassDefFoundError$vmethods	_jc_java_lang_NoClassDefFoundError$vmethods;
typedef const struct _jc_java_lang_NoClassDefFoundError$vtable	_jc_java_lang_NoClassDefFoundError$vtable;
typedef const struct _jc_java_lang_NoClassDefFoundError$vtype	_jc_java_lang_NoClassDefFoundError$vtype;

// Class fields structure
struct _jc_java_lang_NoClassDefFoundError$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_lang_NoClassDefFoundError$fields_struct _jc_java_lang_NoClassDefFoundError$class_fields;

// Constructors
extern void _jc_java_lang_NoClassDefFoundError$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_lang_NoClassDefFoundError$object *) _JC_JCNI_ATTR;
extern void _jc_java_lang_NoClassDefFoundError$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_lang_NoClassDefFoundError$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_lang_NoClassDefFoundError$vmethods {
};

// Vtable
struct _jc_java_lang_NoClassDefFoundError$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Error$vmethods	java_lang_Error;
	_jc_java_lang_LinkageError$vmethods	java_lang_LinkageError;
	_jc_java_lang_NoClassDefFoundError$vmethods	java_lang_NoClassDefFoundError;
};

// Vtype
struct _jc_java_lang_NoClassDefFoundError$vtype {
	_jc_type			type;
	_jc_java_lang_NoClassDefFoundError$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_NoClassDefFoundError$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_lang_NoClassDefFoundError$refs {
    _jc_java_lang_NoClassDefFoundError$sub_refs	java_lang_NoClassDefFoundError;
    _jc_java_lang_LinkageError$sub_refs	java_lang_LinkageError;
    _jc_java_lang_Error$sub_refs	java_lang_Error;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_NoClassDefFoundError$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_lang_NoClassDefFoundError$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Error$sub_nonrefs	java_lang_Error;
    _jc_java_lang_LinkageError$sub_nonrefs	java_lang_LinkageError;
    _jc_java_lang_NoClassDefFoundError$sub_nonrefs	java_lang_NoClassDefFoundError;
};

// Object instance structure
struct _jc_java_lang_NoClassDefFoundError$object {
	_jc_java_lang_NoClassDefFoundError$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_NoClassDefFoundError$vtype	*vtype;
	_jc_java_lang_NoClassDefFoundError$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_NoClassDefFoundError$vtype _jc_java_lang_NoClassDefFoundError$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_NoClassDefFoundError, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_NoClassDefFoundError$class_object;

#endif	/* _JC_java_lang_NoClassDefFoundError_H_ */
